diff --git a/doc/xschem_man/developer_info.html b/doc/xschem_man/developer_info.html
index e5092e87..454e918f 100644
--- a/doc/xschem_man/developer_info.html
+++ b/doc/xschem_man/developer_info.html
@@ -1291,7 +1291,7 @@ C {verilog_timescale.sym} 1050 -100 0 0 {name=s1 timestep="1ns" precision="1ns"
setprop instance inst [tok] [val] [fast]
set attribute 'tok' of instance (name or number) 'inst' to value 'val'
- If 'tok' set to 'prop_ptr' replace whole instance prop_str with 'val'
+ If 'tok' set to 'allprops' replace whole instance prop_str with 'val'
If 'val' not given (no attribute value) delete attribute from instance
If 'tok' not given clear completely instance attribute string
If 'fast' argument if given does not redraw and is not undoable
diff --git a/src/scheduler.c b/src/scheduler.c
index 8051fafe..7dac5fb2 100644
--- a/src/scheduler.c
+++ b/src/scheduler.c
@@ -4611,7 +4611,7 @@ int xschem(ClientData clientdata, Tcl_Interp *interp, int argc, const char * arg
*
* setprop instance inst [tok] [val] [fast]
* set attribute 'tok' of instance (name or number) 'inst' to value 'val'
* If 'tok' set to 'prop_ptr' replace whole instance prop_str with 'val'
* If 'val' not given (no attribute value) delete attribute from instance
* If 'tok' not given clear completely instance attribute string
* If 'fast' argument if given does not redraw and is not undoable
@@ -4683,7 +4683,7 @@ int xschem(ClientData clientdata, Tcl_Interp *interp, int argc, const char * arg
xctx->prep_hi_structs=0;
if(argc > 4 && !strcmp(argv[4], "name") && fast == 0) hash_names(-1, XINSERT);
if(argc > 5) {
- if(!strcmp(argv[4], "prop_ptr")) {
+ if(!strcmp(argv[4], "allprops")) {
hash_names(-1, XINSERT);
my_strdup2(_ALLOC_ID_, &subst, argv[5]);
} else {
@@ -4611,7 +4611,7 @@ int xschem(ClientData clientdata, Tcl_Interp *interp, int argc, const char * arg
* setprop instance inst [tok] [val] [fast]
* set attribute 'tok' of instance (name or number) 'inst' to value 'val'
- * If 'tok' set to 'prop_ptr' replace whole instance prop_str with 'val'
+ * If 'tok' set to 'allprops' replace whole instance prop_str with 'val'
* If 'val' not given (no attribute value) delete attribute from instance
* If 'tok' not given clear completely instance attribute string